# Major digit of the proj so version
%global proj_somaj 12
%global compdir %(dirname $(pkg-config --variable=compatdir bash-completion))

%define _requires_exceptions devel\(libogdi31.*\)\\|devel\(libcfitsio.*\)\\|libgrass
%define major 20
%define libname %mklibname %{name} %{major}
%define libnamedev %mklibname %{name} -d
%define libnamedevstat %mklibname %{name} -d -s

%define build_libgrass 0
%{?with_libgrass: %define build_libgrass 1}

%define ogdidir %{_includedir}
%define ogdidir %{_includedir}/ogdi

Name: gdal
Version: 2.1.3
Release: %mkrel 3
Summary: The Geospatial Data Abstraction Library (GDAL)
Group: Sciences/Geosciences
License: MIT
URL: http://www.gdal.org/
Source: http://download.osgeo.org/gdal/%{name}-%{version}.tar.xz
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot
Patch1:    %{name}-g2clib.patch
Patch2:    %{name}-jni.patch
Patch3:    %{name}-completion.patch
Patch8:    %{name}-1.9.0-java.patch
Patch103:  gdal-1.6.0-fix-libname.patch
BuildRequires: bash-completion
BuildRequires:	libpng-devel
BuildRequires:	zlib-devel
BuildRequires:	geotiff-devel >= 1.2.0
BuildRequires:	libpng-devel
BuildRequires:	%{_lib}gif-devel
BuildRequires:	%{_lib}poppler-devel
BuildRequires:	%{_lib}tiff-devel
BuildRequires:	postgresql9.6-devel
BuildRequires:	libjpeg-devel
BuildRequires:	proj-devel >= 4.9.3
BuildRequires:  doxygen
%if %{build_libgrass}
Requires:	grass >= 6.4.0
BuildRequires:	grass
%else
BuildConflicts:	%mklibname -d grass 5 0
%endif
BuildRequires:	libjasper-devel
BuildConflicts:	%{_lib}jasper1.701_1-devel
BuildRequires:	libgeos-devel >= 2.2.3
BuildRequires:	netcdf-devel >= 3.6.2
BuildRequires:	ogdi-devel
BuildRequires:	cfitsio-devel
BuildRequires:	python-numpy-devel
BuildRequires:	python-setuptools
BuildRequires:	sqlite3-devel
BuildRequires:	librx-devel
BuildRequires:	unixODBC-devel
BuildRequires:  xerces-c-devel
BuildRequires:	hdf5-devel
BuildRequires:	swig
BuildRequires:  gd-devel
BuildRequires:  gcc-c++
BuildRequires:  lzma-devel
BuildRequires:  mysql-devel
BuildRequires:  php-devel
BuildRequires:  %{_lib}curl-devel
BuildRequires:  g2clib-devel
Requires: gpsbabel
%if "%{_lib}" == "lib"
Requires: libproj.so.%{proj_somaj}
%else
Requires: libproj.so.%{proj_somaj}()(64bit)
%endif


%description
The Geospatial Data Abstraction Library (GDAL) is a unifying
C/C++ API for accessing raster geospatial data, and currently
includes formats like GeoTIFF, Erdas Imagine, Arc/Info
Binary, CEOS, DTED, GXF, and SDTS. It is intended to provide
efficient access, suitable for use in viewer applications,
and also attempts to preserve coordinate systems and metadata.
Python, C, and C++ interfaces are available.

%package python
Summary: The Python bindings for the GDAL library
Group: Development/Python
Requires: %{libname}
%py_requires -d

%description python
The Python bindings for the GDAL library

%package -n %{libname}
Summary: Libraries required for the GDAL library
Group: System/Libraries
Provides: lib%{name} = %{version}

%description -n %{libname}
Libraries required for the GDAL library

%package -n %{libnamedev}
Summary: Development files for using the GDAL library
Group: Development/Libraries
Requires: %{libname}
Provides: lib%{name}-devel = %{version}
Provides: %{name}-devel = %{version}
Conflicts:	%{_lib}jasper1.701_1-devel

%description -n %{libnamedev}
Development files for using the GDAL library

%package -n %{libnamedevstat}
Summary: Development files for using the GDAL library
Group: Development/Libraries
Requires: %{libnamedev} = %{version}-%{release}
Conflicts:	%{_lib}jasper1.701_1-devel

%description -n %{libnamedevstat}
Development files for using the GDAL library

%prep
%setup -q -n %{name}-%{version}
%patch1 -p1 -b .g2clib~
%patch2 -p1 -b .jni~
%patch3 -p1 -b .completion~
%patch8 -p1 -b .java~
%patch103 -p0 -b .libname

#bundled lib
rm -r frmts/grib/degrib18/g2clib-1.0.4

# Fix mandir
sed -i "s|^mandir=.*|mandir='\${prefix}/share/man'|" configure configure.in

# libproj is dlopened; upstream sources point to .so, which is usually not present
# http://trac.osgeo.org/gdal/ticket/3602
sed -i 's|libproj.so|libproj.so.%{proj_somaj}|g' ogr/ogrct.cpp


%build
autoconf
%configure2_5x \
        CPPFLAGS=-D_XOPEN_SOURCE=700 \
        LIBS=-lgrib2c \
	--enable-static \
	--datadir=%_datadir/gdal \
	--includedir=%_includedir/gdal \
        --with-dods-root=no \
        --with-ogdi=%{ogdidir} \
        --with-cfitsio=yes \
        --with-geotiff=yes   \
        --with-libtiff=yes   \
        --with-libz=%_prefix      \
        --with-netcdf=%_prefix    \
        --with-hdf5=%_prefix      \
        --with-geos               \
        --with-jasper             \
        --with-png                \
        --with-poppler            \
        --with-gif                \
        --with-jpeg               \
        --with-odbc               \
        --with-sqlite3            \
        --with-mysql              \
        --with-curl               \
        --with-python             \
        --without-php                \
        --with-xerces=%_prefix         \
        --with-xerces-lib='-lxerces-c' \
        --with-xerces-inc=%_includedir \
        %if %{build_libgrass}
    	    --with-grass=%_libdir/grass64     \
        %endif
        --with-threads            \
        --with-liblzma=yes        \
        --without-bsb
       
# make the build break if wms support is not enabled
#if [ "$(cat config.log | grep FORMATS | grep wms)" = "" ]; then
#    echo "No WMS support"
#    exit 1
#fi

        
perl -pi -e 's,PYTHON = no,PYTHON = /usr/bin/python,g' GDALmake.opt
make
make docs

%install
rm -Rf %buildroot
mkdir -p %{buildroot}/%py_platsitedir
export PYTHONPATH="%{buildroot}/%py_platsitedir"
export DESTDIR=%{buildroot}
unset PYTHONDONTWRITEBYTECODE
export INST_MAN=%{_mandir}
%makeinstall_std install-man
find %{buildroot} -name '*.la' -delete
%multiarch_binaries %{buildroot}%{_bindir}/gdal-config

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%clean
rm -rf %buildroot

%files
%defattr(-,root,root)
%{compdir}/
%{_datadir}/gdal/
%{_bindir}/*
%{_mandir}/man1/*
%exclude %{_bindir}/gdal-config
%exclude %{_bindir}/multiarch-*
%exclude %{multiarch_bindir}/gdal-config
%exclude %{_mandir}/man1/gdal-config.1.*
%doc NEWS VERSION

%files -n %{libnamedev}
%defattr(-,root,root)
%{_bindir}/%{name}-config
%{_mandir}/man1/gdal-config.1.*
%{_libdir}/*.so
%{_libdir}/pkgconfig/gdal.pc
%{_includedir}/*
%_docdir/*
%multiarch %{multiarch_bindir}/gdal-config

%files -n %{libnamedevstat}
%defattr(-,root,root)
%{_libdir}/*.a

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/*.so.%{major}*

%files python
%defattr(-,root,root,-)
%py_platsitedir/*


%changelog
* Mon Feb 05 2018 adrianomorselli <adrianomorselli> 2.1.3-3uplos2018
- rebuild for updates

* Sun Jun 25 2017 adrianomorselli <adrianomorselli> 2.1.3-2uplos2017
- update
